
%% Basic code to access the data and sample calculation of ON/OFF maps 

load expt4.mat % load an example dataset 

% Description of variables 

% kern_on [height x width x #on_cells] - is the Gaussian fit to
% monocontrast on cells.  Similarly for kern_off.

% kern_both_on [height x width x #both_cells] - Gaussian fit to the ON
% kernel of cells with significant ON and OFF kernels. Similarly, for
% kern_both_off

% uv_on [#on_cells x 3] each row contains the (x,y,z) cortical coordinates.
% (x,y) are in pixels [but 1pix = 1.02um at this magnification] and z is the
% index of the optical plane 1 is at the top and increases as we move down.

% uv_off [#off_cells x 3] Same for OFF cells

% xy_on [#on_cells x 2] Coordinates of the center of the ON kernel on the
% visual field (coordinates are in "tile" units ~5.5 deg of visual angle). 

% xy_off same for monocontrast OFF cells. 

% xy_both_on - visual coordinatges of ON kernel for cells with both ON and
% OFF kernels. xy_both_off - similar for OFF kernels. 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Lets take a look at one of the kernels of a monocontrast ON cell

close all
figure(1)
imagesc(squeeze(kern_on(:,:,25)));
xlabel('Azimuth')
ylabel('Elevation')
hold on
plot(17.5,4.5,'r+','markersize',20)
axis equal tight
figure(gcf)

%% Lets plot the ON/OFF monocontrast cells in cortical space (projecting depth)

figure(2)
h = scatter(uv_on(:,1),uv_on(:,2),'red','filled');
h.MarkerFaceAlpha = 0.35;
hold on
h = scatter(uv_off(:,1),uv_off(:,2),'blue','filled');
h.MarkerFaceAlpha = 0.35;
axis([0 796 0 512])
axis equal 

%% We can use a Gaussian kernel to estimate the density of each class

% Lets look at distribution of don_off across ON/OFF domains

uv_on = uv_on(:,1:2);   % drop z coordinate
uv_off = uv_off(:,1:2);

non = size(uv_on,1);    % number of ON  RFs
noff = size(uv_off,1);  % number of OFF RFs
    
ui = 1:4:796;           % Subsample in native space
vi = 1:4:512;
[grid_u,grid_v] = meshgrid(ui,vi);
UV = [grid_u(:) grid_v(:)];

bw = 30;                % Bandwidth of Gaussian kernel 

% estimate density of original data

fon_uv = mvksdensity(uv_on,UV,...
    'Bandwidth',[bw bw],...
    'Kernel','normpdf');
fon_uv = reshape(fon_uv,size(grid_u));

foff_uv = mvksdensity(uv_off,UV,...
    'Bandwidth',[bw bw],...
    'Kernel','normpdf');
foff_uv = reshape(foff_uv,size(grid_u));

figure(3)
subplot(1,3,1)
imagesc(fon_uv)
title('ON density')
axis equal off
subplot(1,3,2)
imagesc(foff_uv)
title('OFF density')
axis equal off
subplot(1,3,3)
imagesc(fon_uv-foff_uv)
title('ON-OFF fluctuations')
axis equal off



